@@ -1,7 +1,21 @@
 #! /bin/sh
+#
+# Copyright (c) 1998-1999 peter memishian (meem), meem@gnu.org
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2, or (at your option)
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# General Public License for more details.
+#
+# SCCS "@(#)check-server.sh	1.2	99/10/29 meem"
+
 #
 # check-server.sh: diagnose common problems on the lpd server side.
-# $Id: check-server.sh,v 1.2 1999/09/05 02:04:35 meem Exp $	
 #
 
 if [ $# -lt 2 ]; then
@@ -19,7 +33,7 @@ LOCAL_PRINTER=$2
 # be there at all [it might be started by inetd]).
 #
 
-telnet 127.0.0.1 515 2>&1 | grep -i "refused" 2>&1 > /dev/null
+telnet 127.0.0.1 515 2>&1 | grep -i "refused" > /dev/null 2>&1
 if [ $? -ne 1 ]; then
     echo "$0: lpd does not appear to be currently running."
     RETVAL=1
@@ -31,7 +45,7 @@ fi
 
 for FILE in /etc/printcap /etc/printers.conf; do 
     if [ -f $FILE ]; then
-	grep '^[ 	]*'$LOCAL_PRINTER: $FILE 2>&1 > /dev/null
+	grep '\(^[ 	]*\||\)'$LOCAL_PRINTER'[:|]' $FILE > /dev/null 2&>1
 	if [ $? -ne 0 ]; then
 	    echo "$0: no entry for printer \`$LOCAL_PRINTER' in $FILE"
 	    RETVAL=1
@@ -46,7 +60,7 @@ done
 FOUND=0
 for FILE in /etc/hosts.equiv /etc/hosts.lpd; do
     if [ -f $FILE ]; then
-	grep $INCOMING_HOST $FILE 2>&1 > /dev/null
+	grep $INCOMING_HOST $FILE > /dev/null 2>&1 
 	if [ $? -eq 0 ]; then
 	    FOUND=$FILE
 	fi
