@@ -1,8 +1,5 @@
-#ifndef	INTL_H
-#define	INTL_H
-
 /*
- * Copyright (c) 1998 peter memishian (meem), meem@gnu.org
+ * Copyright (c) 1998-1999 peter memishian (meem), meem@gnu.org
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,14 +10,32 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
- *
- * $Id: intl.h,v 1.4 1998/12/13 23:16:27 meem Exp $
  */
 
-#include <libintl.h>
+#pragma ident "@(#)intl.h	1.2	01/01/01 meem"
+
+#ifndef	INTL_H
+#define	INTL_H
+
 #include <locale.h>
 
+#ifdef	ENABLE_NLS
+
+#include <libintl.h>
 #define	_(string)	gettext(string)
 #define	N_(string)	gettext_noop(string)
 
+#else
+
+/*
+ * No NLS -- stub out the functions.
+ */
+
+#define	_(string)	string
+#define	N_(string)	string
+#define	bindtextdomain(pkg, localedir)
+#define	textdomain(pkg)
+
+#endif
+
 #endif	/* INTL_H */
